﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;

namespace XamWebGridCustomGrouping
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            //setup the grid to use the sales dataset
            this.igGrid.ItemsSource = Product.LoadData();
        }

        private void igGrid_Loaded(object sender, RoutedEventArgs e)
        {
            //expand the first group - the critical stock items list
          //  this.igGrid.Rows[0].IsExpanded = true;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Button btn = sender as Button;
            if (btn != null)
            {
                Product prod = ((Infragistics.Controls.Grids.UnboundColumnDataContext)(btn.DataContext)).Value as Product;
                if (prod != null)
                {
                    //order minimum quantity of item, then update grid
                    prod.UnitsInStock += prod.ReorderLevel + 10;
                    //force an update of the grid to reflect the data change
                    igGrid.InvalidateData();
                    //expand the first group
                    this.igGrid.Rows[0].IsExpanded = true;
                }
            }
        }

        private void igGrid_GroupByCollectionChanged(object sender, GroupByCollectionChangedEventArgs e)
        {
            var childgrid= sender as XamGrid;
            if (e.NewGroupedColumns.Count > 0)
            {
                childgrid.GroupBySettings.GroupByColumns.Grid.PagerSettings.AllowPaging = PagingLocation.None;
                //((XamGrid)childgrid.GroupBySettings.GroupByColumns.Grid.Parent).PagerSettings.AllowPaging = PagingLocation.Bottom;
            }
           
            childgrid.PagerSettings.AllowPaging = PagingLocation.Bottom;
        }

        private void igGrid_RowExpansionChanged(object sender, RowExpansionChangedEventArgs e)
        {
            if (e.Row.IsExpanded)
            {
                Dispatcher.BeginInvoke(new Action(() =>
                {
                    var rowsPanel = e.Row.Control.Owner as RowsPanel;
                    var pagerPanels = rowsPanel.Children.Where(x => x is PagerCellsPanel).Cast<PagerCellsPanel>();
                    foreach (var panel in pagerPanels)
                    {
                        
                        //if (panel.Visibility == System.Windows.Visibility.Visible && panel.Row != null && panel.Row.Manager.ParentRow != null)
                        //    panel.Visibility = System.Windows.Visibility.Collapsed;
                        //Style style = Application.Current.Resources["myStyle"] as Style;
                        //panel.Style = style;
                        if (panel.Visibility == System.Windows.Visibility.Visible && panel.Row != null && panel.Row.Manager.ParentRow != null)
                        {
                            var pagercellcontrol = panel.Children.OfType<PagerCellControl>().FirstOrDefault();
                            //panel.Visibility = System.Windows.Visibility.Collapsed;
                            pagercellcontrol.Style = Resources["pccChild"] as Style;

                            var pagercontrol = panel.Children.OfType<PagerControl>().FirstOrDefault();
                            pagercontrol.Style = Resources["pccChild"] as Style;

                            panel.Row.ColumnLayout.PagerSettings.AllowPaging = PagingLocation.Bottom;
                        }
                        //else
                        //{
                        //    Style style = Resources["pcc"] as Style;
                        //    panel.Style = style;
                        //}

                    }
                }));
            }
        }
    }
    public class XamGridEx : XamGrid
    {

        #region Active Child Item
        public object CurrentActiveItem
        {
            get { return (object)GetValue(CurrentActiveItemProperty); }
            set { SetValue(CurrentActiveItemProperty, value); OnPropertyChanged("CurrentActiveItem"); }
        }

        // Using a DependencyProperty as the backing store for CurrentActiveItem.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty CurrentActiveItemProperty =
            DependencyProperty.Register("CurrentActiveItem",
            typeof(object),
            typeof(XamGridEx),
            new PropertyMetadata(null,
                (ss, ee) =>
                {
                    if (ss is XamGridEx)
                    {
                        Row row = (ss as XamGridEx).GetChildRowFromDataItem((ss as XamGridEx).Rows, ee.NewValue, null);
                        (ss as XamGridEx).ScrollCellIntoView(row.Cells[0]);
                        row.IsSelected = true;

                    }
                }));
        #endregion

        #region Helper Methods
        internal Row GetChildRowFromDataItem(RowCollection rows, object data, Row result)
        {
            if (result != null)
                return result;
            foreach (Row row in rows)
            {
                if (row.Data.Equals(data))
                {
                    result = row;
                }
                else
                {
                    foreach (ChildBand band in row.ChildBands)
                    {
                        result = GetChildRowFromDataItem(band.Rows, data, result);
                    }
                }
            }

            return result;
        }
        #endregion

        #region Base Overrides
        protected override void OnActiveCellChanged()
        {
            base.OnActiveCellChanged();
            CurrentActiveItem = this.ActiveCell.Row.Data;
        }
        #endregion
    }
}
